@@ -7,11 +7,12 @@ class HelpColorsException(Exception):
     pass
 
 
-def _colorize(text, color=None):
-    if not color or "NO_COLOR" in os.environ:
-        return text
+def _colorize(text, color=None, suffix=None):
+    if not color or os.getenv("NO_COLOR"):
+        return text + (suffix or '')
     try:
-        return '\033[%dm' % (_ansi_colors[color]) + text + _ansi_reset_all
+        return '\033[%dm' % (_ansi_colors[color]) + text + \
+                    _ansi_reset_all + (suffix or '')
     except KeyError:
         raise HelpColorsException('Unknown color %r' % color)
 
